setwd("H:/Courses/BIOS600/Computer Skills/Project")
require(lattice)


# GET DATA
#------------------
data <- read.table(file="example.txt",header=TRUE)
attach(data)
n <- length(X)

SEX <-factor(G,labels=c("Females","Males"))


# Summary Tables
#-------------------
apply(data[,c("H","Y")],2,function(x){c(mean(x),sd(x))})
summary(SEX)
summary(P)


# Scatter Plot
#----------------------
plot(X,Y)
text(X[22],Y[22],"obs 22",col="red",pos=3)
points(X[22],Y[22],pch=15, col="red")


# Histogram
#----------------------

# Possibility 1

par(mfrow=c(2,1))
hist(H[G==0],xlim=c(0,21),freq=FALSE,ylim=c(0,.5),main="Health Scores for Females",xlab="")
hist(H[G==1],xlim=c(0,21),freq=FALSE,ylim=c(0,.5),main="Health Scores for Males",xlab="")

# Possibility 2

histogram(~H|SEX,
  xlab="Health Score",main="Comparison of Male and Female Health Scores")


# Boxplot
#-------------------
par(mfrow=c(1,1))
boxplot(H~SEX,main="Comparison of Male and Female Health Scores")


# Time Series
#-------------------
plot(0:5,TS1 <- tapply(R[G==1],T[G==1],mean),type="l",ylim=c(3,14),xlab="T",ylab="R")
lines(0:5,TS2 <- tapply(R[G==0],T[G==0],mean),lwd=2)

# Add some labels (rather than a legend)

points(5,TS1[6],cex=3,pch=16)
points(5,TS1[6],cex=2.5,pch=16,col="white")
text(5,TS1[6],"M",cex=.7)
points(5,TS2[6],cex=3,pch=16)
points(5,TS2[6],cex=2.5,pch=16,col="white")
text(5,TS2[6],"F",cex=.7)

# Probabilities
#---------------------

#P( W < 1.8 ) when W is normally distributed with mean 1 and variance 2
pnorm(1.8,1,sqrt(2))

#P( V < 23 ) when V is BIN( n = 44, p = 0.4 )
pbinom(23,44,.4)

#P( U > 3 ) when U is Poisson with mean .75
1 - ppois(3,.75)

#P( 1.2 < T < 2.3 ) when T is t( df = 46 )
pt(2.3,46) - pt(1.2,46)

#P( S > 2 ) when S is ?2 with df = 7
1 - pchisq(2,7)

#P( R > 3.2 ) when R is F with df1 = 4 and df2 = 38
1 - pf(3.2,4,38)


# Randomized Block Design
#--------------------------

# Possibility 1

set.seed(345289)
TRT <- rep("Placebo",n)
TRT[OBS %in% sample(OBS[G==1],sum(G)/2,replace=FALSE)] <- "Drug"
TRT[OBS %in% sample(OBS[G==0],(n-sum(G))/2,replace=FALSE)] <- "Drug"
xtabs(~TRT+SEX)

# Possibility 2

TRT2 <- order(runif(n) + G)%%2
xtabs(~TRT+G)

# Summary Table of Groups
mean <- tapply(H,paste(SEX,TRT),mean)
sd <- tapply(H,paste(SEX,TRT),sd)
nums <- tapply(H,paste(SEX,TRT),length)
TRT.tbl <- rbind(mean,sd,nums)
TRT.tbl


# t-test, One Sample
#-------------------------
t.test(H,mu=3.5,correct=FALSE)


# t-test, Two Sample
#-------------------------
t.test(H~G,correct=FALSE,mu=-3)


# proportion test, One Sample
#-----------------------------
prop.test(xtabs(~I(P=="D")),p=.5,correct=FALSE)


# proportion test, Two Sample
#-----------------------------
prop.test(xtabs(~I(P=="D")+G),correct=FALSE)


# r X c table
#-----------------------------
tbl <- xtabs(~G+P)
tbl


# Test of No Association
#-----------------------------
chisq.test(tbl)


# GOF test
#-----------------------------
chisq.test(O <- xtabs(~P),p= p <- c(.5,.01,.4,.09),correct=FALSE)


# Fisher's Exact Test
#-----------------------------
fisher.test(matrix(c(5,3,3,5),nrow=2))


# Wilcoxon-Signed-Rank test
#-----------------------------
wilcox.test(H,correct=FALSE,mu=3.5)


# Wilcoxon-Rank-Sum test
#-----------------------------
wilcox.test(H[G==1],H[G==0],correct=FALSE,conf.int=TRUE,mu=3)


# ANOVA
#-----------------------------
anova(lm(H~P))
