options formdlim='.';
dm 'log;clear;output;clear;';

PROC IMPORT OUT= WORK.EXAMPLE 
            DATAFILE= "H:\Courses\BIOS600\Computer Skills\Project\example.txt" 
            DBMS=DLM REPLACE;
     DELIMITER=' '; 
     GETNAMES=YES;
     DATAROW=2; 
RUN;

proc format;
  value GF 
    0 = 'Female' 
    1 = "Male";
  value $PF
    'D' = 'Democrat' 
    'R' = 'Republican' 
    'O' = 'Other'
	'U' = 'Unaffiliated';
  value TRT
    0 = 'Placebo'
	1 = 'Drug';

data example;
  set example;
  format G GF. P $PF.;
  label G='Gender' P='Political Party' H='Health Score' X='HBA1C %' Y='Hours Exercising (daily)' T='Time' R='Income';
  length mylabel $6.;
  if OBS eq 22 then mylabel = "OBS 22";
    else mylabel="";

/*Summary Table*/

proc tabulate data=example;
  var H Y;
  class G P;
  tables H Y, N Mean STD;
  tables G P, N Colpctn;
  format G GF. P $PF.;

/*Scatter and Boxplot*/

proc sgplot data=example;
  scatter X=X Y=Y / datalabel=mylabel;
  hbox H / category=g;

/*Histogram*/

proc sgpanel data=example;
  panelby G;
  histogram H;

/*Time Series Plot by Gender*/

proc sort data=example;
  by G T;

proc means data=example noprint;
  by G T;
  var R;
  output out=LP mean=meanR;

proc sgplot data=LP;
  series X = T Y = meanR / group=G;

/*Probabilities*/

data _NULL_;
  p1 = CDF('NORMAL',1.8,1,1.414);
  p2 = CDF('BINOMIAL',23,.4,44);
  p3 = 1 - CDF('POISSON',3, .75);
  p4 = CDF('T',2.3,46)-CDF('T',1.2,46);
  p5 = 1 - CDF('CHISQUARE',2,7);
  p6 = 1 - CDF('F',3.2,4,38);
  put p1 -- p6;

/*Randomization and Summary*/

data example;
  set example;
  RN = ranuni(2358453) + G;

proc sort data=example;
  by RN;

data example;
  set example;
  TRT = mod(_N_,2);
  format TRT TRT.;

proc tabulate data=example;
  var H;
  class G TRT;
  tables TRT="",G=""*H=""*(N mean);

/*t Test, One Sample*/

proc ttest data=example alpha=0.01 h0=3.5;
  var H;

/*t Test, Two Sample*/

proc ttest data=example alpha=0.1 h0=-3;
  class g;
  var H;

/*Proportion Test, One Sample*/

data example;
  set example;
  D = 1*(P='D');

proc freq data=example;
  tables D / binomial;

/*Proportion Test, Two Sample*/

proc freq data=example;
  tables G*D / riskdiff(equal) chisq;

/*Test of No Association*/

proc freq data=example;
  tables G*P / chisq;

/*GOF Test*/

proc freq data=example;
  tables P / testp=(50 1 40 09);

/*Fisher's Test*/

data temp;
  input resident school count;
  datalines;
  1 1 5
  1 0 3
  0 1 3
  0 0 5
  ;

proc freq data=temp;
  tables resident*school / chisq;
  weight count;

/*Wilcoxon Sign Rank Test*/

proc univariate data=example mu0=3.5;
  var H;

/*Wilcoxon Rank Sum Test*/

data example;
  set example;
  newH = H;
  if G = 0 then newH = H + 3;

proc npar1way data=example wilcoxon;
  var newH;
  class G;

/*ANOVA*/

proc glm data=example;
  class P;
  model H = P;

/*Regression*/

proc glm data=example;
  model H = X Y / solution;



run;
quit;
